@@ -1074,17 +1074,7 @@ void TopLevel::exportGraph()
 {
     if (!_data || !_function) return;
 
-    QString n = QStringLiteral("callgraph.dot");
-    GraphExporter ge(_data, _function, _eventType, _groupType, n);
-    ge.writeDot();
-
-#ifdef Q_OS_UNIX
-    // shell commands only work in UNIX
-    QString cmd = QStringLiteral("(dot %1 -Tps > %2.ps; xdg-open %3.ps)&")
-                  .arg(n).arg(n).arg(n);
-    if (::system(QFile::encodeName( cmd ))<0)
-        qDebug() << "TopLevel::exportGraph: can not run " << cmd;
-#endif
+    GraphExporter::savePrompt(this, _data, _function, _eventType, _groupType, nullptr);
 }
 
 
@@ -1759,7 +1749,7 @@ void TopLevel::layoutNext()
     _multiView->restoreLayout(layoutPrefix.arg(_layoutCurrent), key);
 
     if (0) qDebug() << "TopLevel::layoutNext: current "
-                    << _layoutCurrent << endl;
+                    << _layoutCurrent;
 }
 
 void TopLevel::layoutPrevious()
@@ -1775,7 +1765,7 @@ void TopLevel::layoutPrevious()
     _multiView->restoreLayout(layoutPrefix.arg(_layoutCurrent), key);
 
     if (0) qDebug() << "TopLevel::layoutPrevious: current "
-                    << _layoutCurrent << endl;
+                    << _layoutCurrent;
 }
 
 void TopLevel::layoutSave()
