@@ -60,7 +60,7 @@ public:
     TraceInstrJump* instrJump() const { return _instrJump; }
     TraceInstrJump* jump(int i) const { return _jump[i]; }
     int jumpCount() const { return _jump.size(); }
-    bool operator< ( const QTreeWidgetItem & other ) const Q_DECL_OVERRIDE;
+    bool operator< ( const QTreeWidgetItem & other ) const override;
 
     void updateGroup();
     void updateCost();
@@ -88,9 +88,9 @@ class InstrItemDelegate : public QItemDelegate
 public:
     explicit InstrItemDelegate(InstrView *parent);
     void paint(QPainter *painter, const QStyleOptionViewItem &option,
-               const QModelIndex & index ) const Q_DECL_OVERRIDE;
+               const QModelIndex & index ) const override;
     QSize sizeHint(const QStyleOptionViewItem &option,
-                   const QModelIndex &index) const Q_DECL_OVERRIDE;
+                   const QModelIndex &index) const override;
 
 protected:
     void paintArrows(QPainter *p,
