@@ -36,24 +36,24 @@ class SourceView : public QTreeWidget, public TraceItemView
 
 public:
     explicit SourceView(TraceItemView* parentView,
-                        QWidget* parent = 0);
+                        QWidget* parent = nullptr);
 
-    QWidget* widget() Q_DECL_OVERRIDE { return this; }
-    QString whatsThis() const Q_DECL_OVERRIDE;
+    QWidget* widget() override { return this; }
+    QString whatsThis() const override;
     int arrowLevels() { return _arrowLevels; }
 
-protected slots:
+protected Q_SLOTS:
     void context(const QPoint &);
     void selectedSlot(QTreeWidgetItem*, QTreeWidgetItem*);
     void activatedSlot(QTreeWidgetItem*,int);
     void headerClicked(int);
 
 protected:
-    void keyPressEvent(QKeyEvent* event) Q_DECL_OVERRIDE;
+    void keyPressEvent(QKeyEvent* event) override;
 
 private:
-    CostItem* canShow(CostItem*) Q_DECL_OVERRIDE;
-    void doUpdate(int, bool) Q_DECL_OVERRIDE;
+    CostItem* canShow(CostItem*) override;
+    void doUpdate(int, bool) override;
     void refresh();
     void updateJumpArray(uint,SourceItem*,bool,bool);
     bool searchFile(QString&, TraceFunctionSource*);
