@@ -42,6 +42,7 @@
 #include <QMessageBox>
 #include <QStatusBar>
 #include <QWhatsThis>
+#include <QWindow>
 
 #ifdef QT_DBUS_SUPPORT
 #include <QDBusConnection>
@@ -80,8 +81,8 @@ QCGTopLevel::QCGTopLevel()
 
     createActions();
     createDocks();
-    createMenu();
     createToolbar();
+    createMenu();
 
     _multiView = new MultiView(this, this);
     _multiView->setObjectName(QStringLiteral("MultiView"));
@@ -109,9 +110,34 @@ QCGTopLevel::QCGTopLevel()
 
 QCGTopLevel::~QCGTopLevel()
 {
+#ifdef Q_OS_MAC
+    // hacky way to reinstall the dock, since each toplevel has a dock menu,
+    // we don't do any global menu stuff on mac beyond what qt gives us, and
+    // when the last window that installed the dock menu dies, it goes away.
+    // reinstall it into another window if we can.
+    auto windowList = QApplication::topLevelWidgets();
+    for (int i = 0; i < windowList.size(); i++) {
+        QWidget *topLevelRaw = windowList[i];
+        if (QCGTopLevel *topLevel = qobject_cast<QCGTopLevel*>(topLevelRaw)) {
+            if (topLevel != this) {
+                topLevel->reinstallMacDock();
+                break;
+            }
+        }
+    }
+#endif
     delete _data;
 }
 
+void QCGTopLevel::reinstallMacDock()
+{
+#ifdef Q_OS_MAC
+    if (macDockMenu != nullptr) {
+        this->macDockMenu->setAsDockMenu();
+    }
+#endif
+}
+
 // reset the visualization state, e.g. before loading new data
 void QCGTopLevel::resetState()
 {
@@ -353,6 +379,11 @@ void QCGTopLevel::createActions()
     _openAction->setStatusTip(tr("Open profile data file"));
     connect(_openAction, SIGNAL(triggered()), this, SLOT(load()));
 
+    _closeAction = new QAction(tr("&Close"), this);
+    _closeAction->setShortcuts(QKeySequence::Close);
+    _closeAction->setStatusTip(tr("Close the current window"));
+    connect(_closeAction, SIGNAL(triggered()), this, SLOT(close()));
+
     _addAction = new QAction(tr( "&Add..." ), this);
     _addAction->setStatusTip(tr("Add profile data to current window"));
     connect(_addAction, SIGNAL(triggered(bool)), SLOT(add()));
@@ -369,9 +400,10 @@ void QCGTopLevel::createActions()
             this, &QCGTopLevel::recentFilesTriggered);
 
     _exitAction = new QAction(tr("E&xit"), this);
+    _exitAction->setMenuRole(QAction::QuitRole);
     _exitAction->setShortcut(tr("Ctrl+Q"));
     _exitAction->setStatusTip(tr("Exit the application"));
-    connect(_exitAction, &QAction::triggered, this, &QWidget::close);
+    connect(_exitAction, &QAction::triggered, this, &QApplication::closeAllWindows);
 
     // view menu actions
 
@@ -546,15 +578,28 @@ void QCGTopLevel::createActions()
 
     // settings menu actions
     _configureAction = new QAction(tr("&Configure..."), this);
+    _configureAction->setMenuRole(QAction::PreferencesRole);
     _configureAction->setStatusTip(tr("Configure QCachegrind"));
     connect(_configureAction, SIGNAL(triggered()), this, SLOT(configure()));
 
+    // window menu actions
+    _minimizeAction = new QAction(tr("&Minimize"), this);
+    _minimizeAction->setShortcut(Qt::CTRL + Qt::Key_M);
+    connect(_minimizeAction, &QAction::triggered, this, &QWidget::showMinimized);
+
+    _zoomAction = new QAction(tr("&Zoom"), this);
+    // on macOS, zoom doesn't have exactly the same semantics as maximize
+    // (it creates the best fit), but maximize is the usual copout answer
+    connect(_zoomAction, &QAction::triggered, this, &QWidget::showMaximized);
+
     // help menu actions
     _aboutAction = new QAction(tr("&About QCachegrind..."), this);
+    _aboutAction->setMenuRole(QAction::AboutRole);
     _aboutAction->setStatusTip(tr("Show the application's About box"));
     connect(_aboutAction, &QAction::triggered, this, &QCGTopLevel::about);
 
     _aboutQtAction = new QAction(tr("About Qt..."), this);
+    _aboutQtAction->setMenuRole(QAction::AboutQtRole);
     connect(_aboutQtAction, &QAction::triggered, qApp, &QApplication::aboutQt);
 
     // toolbar actions
@@ -578,6 +623,8 @@ void QCGTopLevel::createMenu()
     fileMenu->addSeparator();
     fileMenu->addAction(_exportAction);
     fileMenu->addSeparator();
+    fileMenu->addAction(_closeAction);
+    fileMenu->addSeparator();
     fileMenu->addAction(_exitAction);
 
     QMenu* layoutMenu = new QMenu(tr("&Layout"), this);
@@ -595,7 +642,9 @@ void QCGTopLevel::createMenu()
     viewMenu->addAction(_secondaryMenuAction);
     viewMenu->addAction(_groupingMenuAction);
     viewMenu->addSeparator();
+    viewMenu->addAction(tb->toggleViewAction());
     viewMenu->addMenu(layoutMenu);
+    viewMenu->addAction(_sidebarMenuAction);
     viewMenu->addAction(_splittedToggleAction);
     viewMenu->addAction(_splitDirectionToggleAction);
     viewMenu->addSeparator();
@@ -603,16 +652,30 @@ void QCGTopLevel::createMenu()
     viewMenu->addAction(_percentageToggleAction);
     viewMenu->addAction(_expandedToggleAction);
     viewMenu->addAction(_hideTemplatesToggleAction);
+    viewMenu->addSeparator();
+    viewMenu->addAction(_configureAction);
 
     QMenu* goMenu = mBar->addMenu(tr("&Go"));
     goMenu->addAction(_backAction);
     goMenu->addAction(_forwardAction);
     goMenu->addAction(_upAction);
+    fileMenu->addAction(_exitAction);
 
-    QMenu* settingsMenu = mBar->addMenu(tr("&Settings"));
-    settingsMenu->addAction(_sidebarMenuAction);
-    settingsMenu->addSeparator();
-    settingsMenu->addAction(_configureAction);
+#ifdef Q_OS_MAC
+    // class level for ease of manipulation
+    this->windowMenu = mBar->addMenu(tr("&Window"));
+    this->windowMenu->addAction(_minimizeAction);
+    this->windowMenu->addAction(_zoomAction);
+    connect(this->windowMenu, &QMenu::aboutToShow, this, &QCGTopLevel::windowListAboutToShow);
+    connect(this->windowMenu, &QMenu::triggered, this, &QCGTopLevel::windowListTriggered);
+
+    // right-clicking the dock icon should be a window list
+    this->macDockMenu = new QMenu(this);
+    connect(this->macDockMenu, &QMenu::aboutToShow, this, &QCGTopLevel::macDockMenuAboutToShow);
+    // it can reuse the same events, it just needs a diff menu structure
+    connect(this->macDockMenu, &QMenu::triggered, this, &QCGTopLevel::windowListTriggered);
+    reinstallMacDock();
+#endif
 
     QMenu* helpMenu = mBar->addMenu(tr("&Help"));
     helpMenu->addAction(QWhatsThis::createAction(this));
@@ -623,7 +686,7 @@ void QCGTopLevel::createMenu()
 
 void QCGTopLevel::createToolbar()
 {
-    QToolBar* tb = new QToolBar(tr("Main Toolbar"), this);
+    tb = new QToolBar(tr("Main Toolbar"), this);
     tb->setObjectName(QStringLiteral("main-toolbar"));
     addToolBar(Qt::TopToolBarArea, tb);
 
@@ -795,7 +858,7 @@ void QCGTopLevel::load()
     files = QFileDialog::getOpenFileNames(this,
                                           tr("Open Callgrind Data"),
                                           _lastFile,
-                                          tr("Callgrind Files (callgrind.*);;All Files (*)"));
+                                          tr("Callgrind Files (callgrind.* cachegrind.*);;All Files (*)"));
     load(files);
 }
 
@@ -898,17 +961,7 @@ void QCGTopLevel::exportGraph()
 {
     if (!_data || !_function) return;
 
-    QString n = QStringLiteral("callgraph.dot");
-    GraphExporter ge(_data, _function, _eventType, _groupType, n);
-    ge.writeDot();
-
-#ifdef Q_OS_UNIX
-    // shell commands only work in UNIX
-    QString cmd = QStringLiteral("(dot %1 -Tps > %2.ps; xdg-open %3.ps)&")
-                  .arg(n).arg(n).arg(n);
-    if (::system(QFile::encodeName( cmd ))<0)
-        qDebug() << "QCGTopLevel::exportGraph: can not run " << cmd;
-#endif
+    GraphExporter::savePrompt(this, _data, _function, _eventType, _groupType, nullptr);
 }
 
 
@@ -1315,6 +1368,7 @@ void QCGTopLevel::setData(TraceData* data)
         if (!_data->command().isEmpty())
             caption += " [" + _data->command() + ']';
     }
+    setWindowFilePath(QDir::toNativeSeparators(_data->traceName()));
     setWindowTitle(caption);
 
     if (!_data || (!_forcePartDock && _data->parts().count()<2))
@@ -1827,6 +1881,50 @@ void QCGTopLevel::partsUnhideAllSlot()
 #endif
 }
 
+void QCGTopLevel::insertWindowList(QMenu* menu)
+{
+    auto windowList = QApplication::topLevelWidgets();
+    auto activeWindow = QApplication::activeWindow();
+    // dock menu this corresponds to (IIRC) last window that installed one,
+    // so using it unless we have to is a bad idea
+    if (activeWindow == nullptr) {
+        activeWindow = this;
+    }
+    for (int i = 0; i < windowList.size(); i++) {
+        QWidget *topLevelRaw = windowList[i];
+        if (QCGTopLevel *topLevel = qobject_cast<QCGTopLevel*>(topLevelRaw)) {
+            QString windowTitle = topLevel->windowTitle();
+            QAction *windowItem = menu->addAction(windowTitle);
+            windowItem->setData(QVariant::fromValue(topLevel));
+            if (topLevel == activeWindow) {
+                windowItem->setCheckable(true);
+                windowItem->setChecked(true);
+            }
+        }
+    }
+}
+
+void QCGTopLevel::windowListAboutToShow()
+{
+    windowMenu->clear();
+
+    windowMenu->addAction(_minimizeAction);
+    windowMenu->addAction(_zoomAction);
+    windowMenu->addSeparator();
+
+    insertWindowList(windowMenu);
+}
+
+void QCGTopLevel::macDockMenuAboutToShow()
+{
+    macDockMenu-> clear();
+
+    insertWindowList(macDockMenu);
+
+    macDockMenu->addSeparator();
+    macDockMenu->addAction(_newAction);
+}
+
 void QCGTopLevel::forwardAboutToShow()
 {
     QMenu *popup = _forwardAction->menu();
@@ -1933,6 +2031,20 @@ void QCGTopLevel::upAboutToShow()
     }
 }
 
+void QCGTopLevel::windowListTriggered(QAction* action)
+{
+    if (action == _minimizeAction || action == _zoomAction) {
+        // these are always in the menu for macOS
+        return;
+    }
+
+    QVariant data = action->data();
+    if (QCGTopLevel* tl = qvariant_cast<QCGTopLevel*>(data)) {
+        tl->activateWindow();
+        tl->raise();
+    }
+}
+
 void QCGTopLevel::forwardTriggered(QAction* action)
 {
     int count = action->data().toInt(nullptr);
